# pysmps
Utilities for parsing MPS and SMPS file formats.
## Installation
You can install this package using PyPI with the command
```bash
pip install pysmps
```
After installation you can import the reader as
```python
from pysmps import smps_loader as smps
```
at the beginning of your python code. For full documentation take a look at the PyPI page, <https://pypi.org/project/pysmps/>.

## TODO
- [ ] Scenario support in sto file parsing.
- [x] Block support in 2-stage problem casting.
